@@ -18,11 +18,11 @@
 #ifndef KGET_H
 #define KGET_H
 
-#include <KService>
 #include <KActionCollection>
 #include <KNotification>
 #include <KLocalizedString>
-#include <KPluginInfo>
+#include <KPluginLoader>
+#include <KPluginFactory>
 
 #include <QNetworkConfigurationManager>
 #include <QDomElement>
@@ -235,7 +235,7 @@ class KGET_EXPORT KGet
         /**
          * @returns a list of pluginInfos associated with all transferFactories
          */
-        static KPluginInfo::List pluginInfos();
+        static QVector<KPluginMetaData> plugins();
 
         /**
          * @returns The factory of a given transfer
@@ -432,7 +432,7 @@ class KGET_EXPORT KGet
         static TransferTreeSelectionModel * m_selectionModel;
 
         //Lists of available plugins
-        static KPluginInfo::List m_pluginInfoList;
+        static QVector<KPluginMetaData> m_pluginList;
         static QList<TransferFactory *> m_transferFactories;
 
         //pointer to the Main window
