@@ -20,7 +20,7 @@ TransferDataSource::TransferDataSource(const QUrl &srcUrl, QObject *parent)
     m_supposedSize(0),
     m_parallelSegments(1),
     m_currentSegments(0),
-    m_capabilities(0)
+    m_capabilities()
 {
     qCDebug(KGET_DEBUG) ;
 }
@@ -38,7 +38,7 @@ Transfer::Capabilities TransferDataSource::capabilities() const
 void TransferDataSource::setCapabilities(Transfer::Capabilities capabilities)
 {
     m_capabilities = capabilities;
-    emit capabilitiesChanged();
+    Q_EMIT capabilitiesChanged();
 }
 
 void TransferDataSource::findFileSize(KIO::fileoffset_t segmentSize)
